Processor.processor — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Processor.processor

Functions

`call_pipeline_with_ack`(pipeline, msg, client) |
`get_hostname_output_path`(output_path) |
`init_connection`(conn, config) |
`init_pipeline`(downloader, extractors_path, ...) |
`processor`(output_path, use_hostname_output, ...) |

Classes

`Listener`(messages, listener_stats) |
`ListnerStats`([messages, last_message_time]) |
`Message`(dr, headers) |